@@ -172,7 +172,7 @@ PyBlosc_destroy(PyObject *self)
 
 static PyObject *
 compress_helper(void * input, size_t nbytes, size_t typesize,
-		int clevel, int shuffle, char *cname){
+                int clevel, int shuffle, char *cname){
 
     int cbytes;
     PyObject *output = NULL;
@@ -237,16 +237,33 @@ PyDoc_STRVAR(compress__doc__,
 static PyObject *
 PyBlosc_compress(PyObject *self, PyObject *args)
 {
+    Py_buffer view;
+    PyObject *output;
     void *input;
     size_t nbytes, typesize;
     int clevel, shuffle;
-    char *cname;
+    char *cname, *format;
 
-    /* require Python string object, typesize, clevel and shuffle agrs */
-    if (!PyArg_ParseTuple(args, "s#niis:compress", &input, &nbytes,
-                          &typesize, &clevel, &shuffle, &cname))
-      return NULL;
-    return compress_helper(input, nbytes, typesize, clevel, shuffle, cname);
+    /* Accept some kind of input followed by
+     * typesize, clevel, shuffle and cname */
+    #if PY_MAJOR_VERSION <= 2
+        /* s* : bytes like object including unicode and anything that supports
+         * the buffer interface */
+        format = "s*niis:compress";
+    #elif PY_MAJOR_VERSION >= 3
+        /* y* :bytes like object EXCLUDING unicode and anything that supports
+         * the buffer interface. This is the recommended way to accept binary
+         * data in Python 3. */
+        format = "y*niis:compress";
+    #endif
+    if (!PyArg_ParseTuple(args, format , &view,
+                        &typesize, &clevel, &shuffle, &cname))
+        return NULL;
+    nbytes = view.len;
+    input = view.buf;
+    output = compress_helper(input, nbytes, typesize, clevel, shuffle, cname);
+    PyBuffer_Release(&view);
+    return output;
 }
 
 PyDoc_STRVAR(get_clib__doc__,
@@ -354,28 +371,50 @@ PyDoc_STRVAR(decompress__doc__,
 static PyObject *
 PyBlosc_decompress(PyObject *self, PyObject *args)
 {
+    Py_buffer view;
     PyObject *result_str;
     void *input, *output;
     size_t nbytes, cbytes;
+    char *format;
+    /* Accept some kind of input */
+    #if PY_MAJOR_VERSION <= 2
+        /* s* : bytes like object including unicode and anything that supports
+         * the buffer interface */
+        format = "s*:decompress";
+    #elif PY_MAJOR_VERSION >= 3
+        /* y* :bytes like object EXCLUDING unicode and anything that supports
+         * the buffer interface. This is the recommended way to accept binary
+         * data in Python 3. */
+        format = "y*:decompress";
+    #endif
 
-    if (!PyArg_ParseTuple(args, "s#:decompress", &input, &cbytes))
+    if (!PyArg_ParseTuple(args, format, &view))
       return NULL;
 
+    cbytes = view.len;
+    input = view.buf;
     /*  fetch the uncompressed size into nbytes */
-    if (!get_nbytes(input, cbytes, &nbytes))
+    if (!get_nbytes(input, cbytes, &nbytes)){
+      PyBuffer_Release(&view);
       return NULL;
+    }
 
     /* Book memory for the result */
-    if (!(result_str = PyBytes_FromStringAndSize(NULL, (Py_ssize_t)nbytes)))
+    if (!(result_str = PyBytes_FromStringAndSize(NULL, (Py_ssize_t)nbytes))){
+      PyBuffer_Release(&view);
       return NULL;
+    }
+
     output = PyBytes_AS_STRING(result_str);
 
     /*  do decompression */
     if (!decompress_helper(input, nbytes, output)){
       Py_XDECREF(result_str);
+      PyBuffer_Release(&view);
       return NULL;
     }
 
+    PyBuffer_Release(&view);
     return result_str;
 }
 
